@@ -4,16 +4,21 @@ use strict;
 use warnings;
 
 package Finance::Shares::Sample;
-use Carp;
 use Finance::Shares::Sample 0.12 qw(%period %function %functype);
 
 $function{simple_average}      = \&simple_average;
 $function{weighted_average}    = \&weighted_average;
 $function{exponential_average} = \&exponential_average;
+$function{avg} = \&simple_average;
+$function{wgt} = \&weighted_average;
+$function{exp} = \&exponential_average;
 
 $functype{simple_average}      = 'a';
 $functype{weighted_average}    = 'a';
 $functype{exponential_average} = 'a';
+$functype{avg} = 'a';
+$functype{wgt} = 'a';
+$functype{exp} = 'a';
 
 =head1 NAME
 
@@ -42,11 +47,12 @@ Finance::Shares::Averages - Moving average lines and tests
 
 This package provides additional methods for L<Finance::Shares::Sample> objects.  The functions provide moving
 average lines.  Once a line has been constructed it may be referred to by a text identifier returned by the
-function.  The functions may also be referred to by their text names in a model specification:
+function.  The functions may also be referred to by their text names in a model specification (full or short
+version):
 
-    simple_average
-    weighted_average
-    exponential_average
+    avg	    simple_average
+    wgt	    weighted_average
+    exp	    exponential_average
 
 They all take the same parameters in hash key/value format.
 All of these keys are optional.
@@ -90,7 +96,7 @@ If given this becomes the visual identifier, shown on the Chart key panel.
 
 sub simple_average {
     my $s = shift;
-    croak "No Finance::Shares::Sample object" unless ref($s) eq 'Finance::Shares::Sample';
+    die "No Finance::Shares::Sample object\n" unless ref($s) eq 'Finance::Shares::Sample';
     my %a = (
 	strict	=> 0,
 	shown	=> 1,
@@ -102,7 +108,7 @@ sub simple_average {
 	@_);
     
     my $base = $s->{lines}{$a{graph}}{$a{line}};
-    croak "No $a{graph} line '$a{line}'" unless $base;
+    die "No $a{graph} line '$a{line}'\n" unless $base;
     
     my $id = line_id('simple', $a{period}, $a{line});
     my $dtype = $s->dates_by();
@@ -125,7 +131,7 @@ Finance::Shares::Sample.
 
 sub weighted_average {
     my $s = shift;
-    croak "No Finance::Shares::Sample object" unless ref($s) eq 'Finance::Shares::Sample';
+    die "No Finance::Shares::Sample object\n" unless ref($s) eq 'Finance::Shares::Sample';
     my %a = (
 	strict	=> 0,
 	shown	=> 1,
@@ -137,7 +143,7 @@ sub weighted_average {
 	@_);
     
     my $base = $s->{lines}{$a{graph}}{$a{line}};
-    croak "No $a{graph} line with if $a{line}" unless $base;
+    die "No $a{graph} line with if $a{line}\n" unless $base;
     
     my $id = line_id('weighted', $a{period}, $a{line});
     my $dtype = $s->dates_by();
@@ -160,7 +166,7 @@ Finance::Shares::Sample.
 
 sub exponential_average {
     my $s = shift;
-    croak "No Finance::Shares::Sample object" unless ref($s) eq 'Finance::Shares::Sample';
+    die "No Finance::Shares::Sample object\n" unless ref($s) eq 'Finance::Shares::Sample';
     my %a = (
 	strict	=> 0,
 	shown	=> 1,
@@ -172,7 +178,7 @@ sub exponential_average {
 	@_);
     
     my $base = $s->{lines}{$a{graph}}{$a{line}};
-    croak "No $a{graph} line with id $a{line}" unless $base;
+    die "No $a{graph} line with id $a{line}\n" unless $base;
     
     my $id = line_id('expo', $a{period}, $a{line});
     my $dtype = $s->dates_by();
